%-------DIPLOMOV PRCE---------
% ====================================
% LOHA VEDEN TEPLA V PALIVOVM PROUTKU
% ====================================
% Autor: Marek Blohoubek
% Verze: 1.0
% Datum: 2020
% ====================================
% <<<<<< INPUTS
% r1,r2,r3 - geometrick charakteristiky palivovho proutku
% proutek,axVrstva,dr,mocnina,n,m,vyhoreni,volba,epsilonT,paprsek - parametry vpotu
% T,vykon,vlastnosti - vstupn matice subkanlov analzy
% cp,eta - vlastnosti vody pi konstantnm tlaku
% >>>>>> OUTPUTS
% globT,globLambdai - pole vstupnch veliin teploty a tepeln vodivosti v rmci geometrie
% grafick vstupy  - teplotn pole vybranho palivovho proutku
%                   - prbh teploty, jej zmny a tepeln vodivosti ve smru radiln souadnice pro vybran paprsek 
%                   - funkce Dirichletovy okrajov podmnky na hranici proutku

clc
%clear all
close all

%-------vstupn geometrick parametry---------
r1=7.8e-3/2; %polomr vrstvy paliva [m]
r2=7.93e-3/2; %polomr vnj vrstvy (horn hranice haliov mezery) [m]
r3=9.1e-3/2; %polomr proutku [m]

%-------vstupn vpotov parametry---------
proutek=1; %vbr analyzovanho proutku
axVrstva=length(T); %vbr ax. vrstvy, pro n budeme teplotn analzu provdt
dr=r3/280; %dlka prostorovho kroku v radilnm smru [m] (obvykle 280)
mocnina=2; %hodnota mocniny proloen okrajov podmnky
n=r3/dr; %poet iterac v radilnm smru (poet prvk=n+1)
m=10; %poet vabranch analyzovanch paprsk v rmci jedn ax. vrstvy (obvykle 24)
vyhoreni=41.3; %vyhoen paliva [MW d / kg U]
prolozeni=8; %mocnina proloen tepeln vodivosti
epsilonT=1; %hodnota zastavovac podmnky pro iterovn teplot v rmci jednoho paprsku [C]
volba=4; %volba vpotov metody (1-CDS,2-DDS,3-MKO,4-MKP)
pocetProutku=19; %celkov poet palivovch proutk

%-------------------------------------------------------------------------------
%-------deklarace okrajov podmnky---------
zas=[1/6 1/3 1/4 1/12]; %mon zastoupen subkanl u jednotlivch proutk

%kad dek pedstavuje sousedn subkanly jednoho z proutk (v pravotoivm systm od nuly do 360)
%prvn a posledn subkanly jsou toton (kvli rotaci)
%proutky s menm potem soused maj posledn prvky dek nulov
soup=[3 2 1 6 5 4 3 2; 1 8 7 24 23 6 1 8; 11 10 9 8 1 2 11 10; 13 12 11 2 3 14 13 12; ...
    12 14 3 4 17 16 12 14; 17 4 5 20 19 18 17 4; 5 6 23 22 21 20 5 6; 7 25+zas(2) 36+zas(2) 24 7 25+zas(2) 0 0; ...
    9 26+zas(3) 25+zas(3) 7 8 9 26+zas(3) 0; 27+zas(2) 26+zas(2) 9 10 27+zas(2) 0 0 0; ...
    28+zas(3) 27+zas(3) 10 11 12 28+zas(3) 0 0; 29+zas(2) 28+zas(2) 12 13 29+zas(2) 28+zas(2) 0 0; ...
    29+zas(3) 13 14 15 30+zas(3) 29+zas(3) 0 0; 30+zas(2) 15 16 31+zas(2) 30+zas(2) 0 0 0; ...
    31+zas(3) 16 17 18 32+zas(3) 31+zas(3) 16 0; 32+zas(2) 18 19 33+zas(2) 32+zas(2) 18 0 0; ...
    19 20 21 34+zas(3) 33+zas(3) 19 20 0; 21 22 35+zas(2) 34+zas(2) 21 22 0 0; ...
    23 24 36+zas(3) 35+zas(3) 22 23 24 0];

for ii=1:length(soup)
    for ij=1:length(soup(1,:))
        if mod(soup(ii,ij),1)==0 && soup(ii,ij)~=0
            soup(ii,ij)=soup(ii,ij)+zas(1);
        end
    end
end

startPozice=zeros(1,pocetProutku);
startPozice(1:11)=-zas(1);
startPozice(12:end)=[-zas(2) -zas(4) -zas(1) -zas(3) -zas(2) -zas(1) -zas(1) -zas(1)];

Tsub=zeros(2,length(soup(1,:))+1); %matice teplot v subkanlech kolem proutk
for ii=1:length(soup(1,:))
    if soup(proutek,ii)~=0
    if ii==1
        Tsub(1,ii)=startPozice(proutek)+mod(soup(proutek,ii),1)/2;
    else
        Tsub(1,ii)=Tsub(1,ii-1)+mod(soup(proutek,ii-1),1)/2+mod(soup(proutek,ii),1)/2;
    end
    
    Tsub(2,ii)=T(fix(soup(proutek,ii)),axVrstva);
    end
end

%oznut vektoru od pebytench hodnot
orez=find(Tsub(1,:)==0);
Tsub=Tsub(:,1:orez(1)-1);
dphi=0.01; %velikost mrnho hlovho kroku 
phi=Tsub(1,1):dphi:Tsub(1,end);
Tokr=zeros(3,length(phi)); %vektor teplotn okrajov podmnky
%(dkov) struktura:| hel natoen | teplota v subkanle | teplota na stn |
Tokr(1,:)=phi;

for ii=1:length(Tokr)
    pom=1;
    while Tokr(1,ii)>=Tsub(1,pom)
        pom=pom+1;
    end
    pomer1=abs(Tsub(1,pom-1)-Tokr(1,ii))^mocnina;
    pomer2=abs(Tsub(1,pom)-Tokr(1,ii))^mocnina;
    delkaKroku=pomer1+pomer2;
    pomer1=pomer1/delkaKroku; %normalizace
    pomer2=pomer2/delkaKroku;
    
    Tokr(2,ii)=pomer1*Tsub(2,pom)+pomer2*Tsub(2,pom-1);
    
    %vpoet teplotn okr. podmnky na stn proutku
    %vpoet souinitele pestupu tepla alfa [W / m2 K]
    index1=vyhledejIndex(T2,Tokr(2,ii)); %hledn prvku s nejbli hodnotou teploty pro ii-t prvek
    subkanal=fix(soup(proutek,pom));
    subkanalvedl=fix(soup(proutek,pom-1));
    
    %vpoet Nusseltova sla
    Pr=(eta(2,index1)*cp(2,index1))/lambda(2,index1); %Prandtlovo slo [-]
    dh=4*(pomer1*vlastnosti(1,subkanal)+pomer2*vlastnosti(1,subkanalvedl))/(pomer1*vlastnosti(6,subkanal)+pomer2*vlastnosti(6,subkanalvedl)); %hydraulick prmr [m]
    G=(pomer1*M(subkanal,axVrstva)+pomer2*M(subkanalvedl,axVrstva))/(pomer1*vlastnosti(1,subkanal)+pomer2*vlastnosti(1,subkanalvedl)); %hustota hmotnostnho toku [kg / m2 s1]
    Re=G*dh/eta(2,index1); %Reynoldsovo slo [-]
    Nu=0.023*Re^0.8*Pr^0.43;
    
    alfa=Nu*lambda(2,index1)/dh; %souinitel pestupu tepla [W / m2 K]
    Apom=2*pi*r3*L;
    Tokr(3,ii)=Tokr(2,ii)+(vykon(proutek)/Apom)/alfa;
end

%-------------------------------------------------------------------------------
%-------vpoet pomocnch veliin---------
qgen=vykon(proutek)/(pi*r1^2*L); %objemov hustota tepelnho toku [W / m3]
tildeq=vykon(proutek)/(L*100); %linern tepeln vkon [W / cm]
T3=19.85:1:500; %vektor teploty pro vpoet tepeln vodivosti lambda

%-------vpoet souinitele tepeln vodiviosti labmda pro jendnotliv vsrtvy---------
%vpoet souinitele tepeln vodivosti lambda pro zirkonov pokryt [W / m K]
lambdaPok=zeros(1,length(T3));
for ii=1:length(T3)
    lambdaPok(ii)=6.50e-17*T3(ii)^6-2.51e-13*T3(ii)^5+3.36e-10*T3(ii)^4-...
        1.74e-7*T3(ii)^3+2.35e-5*T3(ii)^2+1.17e-2*T3(ii)+1.70e1; %tepeln vodivost pokryt [W / m K]
end

%vpoet souinitele tepeln vodivosti lambda pro heliovou mezeru [W / m K]
alfaMtab=[0.0 20.8 41.3 57.0 70.8 79.0; ...
    2848.5 4422.7 8761.8 7511.9 4474.4 5926.8; ...
    3220 4891 10717 11518 11970 7963; ...
    3608 5824 15553 15311 12752 8938; ...
    4047 7074 21612 16191 13621 9774; ...
    4475 8258 22436 17073 14416 10506];
%matice souinitel prostupu tepla v zvislosti na linernm vkonu a vyhoen paliva
%dkov struktura: | vyhoen paliva | vkon 0 | vkon 50 | 100 | 150 | 200 |

%proloen polynomem
vykonyAlfa=[0 50 100 150 200]; %vektor vkon souinitele prostupu tepla
indexVyhoreni=find(vyhoreni==alfaMtab(1,:));
p1=polyfit(vykonyAlfa',alfaMtab(2:end,indexVyhoreni),prolozeni/2);

dq=1; %iteran krok pro prokldn linernho vkonu tildeq
vykony=vykonyAlfa(1):dq:vykonyAlfa(end);
alfaM=zeros(2,length(vykony)); %matice souinitele prostupu tepla pro vybran vyhoen
alfaM(1,:)=vykony;
alfaM(2,:)=polyval(p1,alfaM(1,:));

alfaMOpt=alfaM(2,vyhledejIndex(alfaM(1,:),tildeq));
lambdaHel=alfaMOpt*r2*log(r2/r1); %tepeln vodivost heliov vrstvy [W / m K]

%vpoet souinitele tepeln vodivosti lambda pro palivo [W / m K]
lambdaPalZadane=[300 500 700 900 1100 1300 1500 1700 1900 2100 2300 2500 2700 2900;...
    8.42 6.26 4.98 4.14 3.56 3.15 2.86 2.66 2.54 2.51 2.55 2.67 2.89 3.20;...
    3.85 3.32 2.94 2.72 2.61 2.52 2.42 2.34 2.30 2.31 2.38 2.54 2.77 3.10;...
    3.10 2.75 2.49 2.34 2.29 2.25 2.19 2.15 2.13 2.17 2.26 2.43 2.68 3.01;...
    2.73 2.45 2.25 2.13 2.11 2.09 2.05 2.02 2.03 2.08 2.18 2.36 2.61 2.96;...
    2.48 2.25 2.08 1.99 1.97 1.96 1.94 1.93 1.94 2.00 2.12 2.30 2.56 2.91;...
    2.35 2.15 1.99 1.91 1.90 1.90 1.89 1.88 1.90 1.96 2.08 2.27 2.53 2.89];
%matice tepeln vodivosti pro rzn teploty a hodnoty vyhoen
%(dkov) struktura: teploty [K] | vyhoen 0.0 | vyhoen 20.8 | vyhoen
%41.3 | vyhoen 57.0 | vyhoen 70.8 | 79.0 |

lambdaPalZadane(1,:)=lambdaPalZadane(1,:)-273.15;
dT=10;
lambdaPal=zeros(2,round((lambdaPalZadane(1,end)-lambdaPalZadane(1,1))/dT+1));

%proloen polynomem
p1=polyfit(lambdaPalZadane(1,:),lambdaPalZadane(indexVyhoreni+1,:),prolozeni);
lambdaPal(1,:)=lambdaPalZadane(1,1):dT:lambdaPalZadane(1,end);
lambdaPal(2,:)=polyval(p1,lambdaPal(1,:));

%-------------------------------------------------------------------------------
%-------vpoet teploty v maticov sti proutku (iteran vpoet)---------
globT=zeros(m,round(n)+1); %globln matice teplot
globLambdai=zeros(m,round(n)+1); %globln matice tepeln vodivosti

if volba==4
    %potebn deklarace promnnch pro poteby MKP (celkov poetKP=n, celkov poet Uzl=n+1)
    %lokalizan matice a matice globlnch souadnic uzl
    ilok=zeros(n,2); %lokalizan matice (1 prvek = 1 dek)
    for ii=1:n
        ilok(ii,1)=ii;
        ilok(ii,2)=ii+1;
    end
    
    sourR=zeros(n,2); %globln matice r-ovch souadnic (1 prvek = 1 dek)
    for ii=1:n
        sourR(ii,1)=(ii-1)*dr;
        sourR(ii,2)=sourR(ii,1)+dr;
    end
    
end

%-------------------------------------------------------------------------------
%-------samotn iteran vpoet---------
for ii=1:m
    uhel=ii/m; %mrn hel natoen paprsku (hodnota nlec (0;1))
    ij=1;
    pom1=0;
    %Dirichletova okrajov podmnka
    indexT=vyhledejIndex(Tokr(1,:),uhel);
    Tpoc=Tokr(3,indexT);
    
    %-------------------------------------------------------------------------------
    %deklarace loklnch matic vpotu pro jeden radiln paprsek
    Tpom=zeros(n+1,1); %vektor teplot pro jeden radiln "paprsek"
    Thled=zeros(n+1,1); %vektor hledanch teplot (pro jeden radiln paprsek)
    lambdai=zeros(1,n+2); %vektor souinitele tepeln vodivosti
    
    iterace1=1;
    maxRezT=2000;
    
    %iteran vpoet pes jeden paprsek
    while maxRezT>epsilonT
        Tpom=Thled;
        A=zeros(n+1,n+1); %matice koef. jednotlivch teplot
        b=zeros(n+1,1); %vektor prav strany (vektor zdroj)
        
        for ij=1:n+1
            ri=(ij-1)*dr; %souadnice v radilnm smru (aktuln polomr)
            
            %uren hodnoty lambda pro hladinu ij a ij+1
            if iterace1==1 %poten "nstel" hodnot lambdai
                if ri>=r2 %odpovd teplot 319 C
                    lambdai(ij)=lambdaPok(31);
                    lambdai(ij+1)=lambdaPok(31);
                elseif ri>r1
                    lambdai(ij)=lambdaHel;
                    lambdai(ij+1)=lambdaHel;
                else %odpovd teplot 427 C
                    lambdai(ij)=lambdaPal(2,3);
                    lambdai(ij+1)=lambdaPal(2,3);
                end
            else
                if ri>=r2 %vrstva pokryt
                    index2=vyhledejIndex(T3,Tpom(ij));
                    if ij~=n+1
                        index3=vyhledejIndex(T3,Tpom(ij+1));
                    end
                    lambdai(ij)=lambdaPok(index2);
                    lambdai(ij+1)=lambdaPok(index3);
                elseif ri>r1 %vrstva helia
                    lambdai(ij)=lambdaHel;
                else %vrstva paliva
                    index2=vyhledejIndex(lambdaPal(1,:),Tpom(ij));
                    if ij~=n+1
                        index3=vyhledejIndex(lambdaPal(1,:),Tpom(ij+1));
                    end
                    lambdai(ij)=lambdaPal(2,index2);
                    lambdai(ij+1)=lambdaPal(2,index3);
                end
            end
            
            switch volba
                case 1 %centrln diferenn schma
                    if ij==1
                        A(ij,ij)=-1;
                        A(ij,ij+1)=1;
                    elseif ij==n+1
                        tilder=r1;
                        A(ij,ij-1)=1;
                        b(ij)=(dr*tilder^2*qgen)/(lambdai(ij)*ri)+Tpoc;
                    else
                        if ri<=r1
                            tilder=ri;
                        else
                            tilder=r1;
                        end
                        
                        A(ij,ij+1)=1;
                        A(ij,ij-1)=-1;
                        b(ij)=-(dr*tilder^2*qgen)/(lambdai(ij)*ri);
                    end
                    
                case 2 %dopedn diferenn schma
                    if ij==1
                        A(ij,ij)=-1;
                        A(ij,ij+1)=1;
                    elseif ij==n+1
                        tilder=r1;
                        A(ij,ij)=1;
                        b(ij)=(dr*tilder^2*qgen)/(2*lambdai(ij)*ri)+Tpoc;
                    else
                        if ri<=r1
                            tilder=ri;
                        else
                            tilder=r1;
                        end
                        
                        A(ij,ij+1)=1;
                        A(ij,ij)=-1;
                        b(ij)=-(dr*tilder^2*qgen)/(2*lambdai(ij)*ri);
                    end
                    
                case 3 %metoda konench objem
                    rplus=ri+dr/2;
                    rminus=ri-dr/2;
                    if ij==1
                        lambdaiminus=lambdai(ij);
                        lambdaiplus=(lambdai(ij+1)+lambdai(ij))/2;
                        rminus=ri;
                    elseif ij==n+1
                        lambdaiplus=lambdai(ij)/2;
                        lambdaiminus=(lambdai(ij-1)+lambdai(ij))/2;
                        rplus=ri;
                    else
                        lambdaiplus=(lambdai(ij+1)+lambdai(ij))/2;
                        lambdaiminus=(lambdai(ij-1)+lambdai(ij))/2;
                    end
                    
                    ia=lambdaiplus*rplus/dr;
                    ib=lambdaiminus*rminus/dr;
                    if ri>r1
                        ic=0;
                    else
                        ic=-qgen*dr*ri;
                    end
                    
                    if ij==1
                        A(ij,ij)=-1;
                        A(ij,ij+1)=1;
                    elseif ij==n+1
                        A(ij,ij)=-(ia+ib);
                        A(ij,ij-1)=ib;
                        b(ij)=ic-ia*Tpoc;
                    else
                        A(ij,ij+1)=ia;
                        A(ij,ij)=-(ia+ib);
                        A(ij,ij-1)=ib;
                        b(ij)=ic;
                    end
                    
                otherwise %metoda konench prvk
                    if ij~=n+1
                        er=sourR(ij,:)'; %globln r-ov souadnice analyzovanho prvku
                        
                        lambdaimkp=(lambdai(ij)+lambdai(ij+1))/2; %souinitel tepeln vodivosti povaujeme na KP za konstantn - bereme aritmetick prmr z uzlovch hodnot
                        Ae=[1 -1;-1 1]*lambdaimkp/2; %lokln matice tuhosti
                        if er(2)<=r1
                            be=qgen*[dr^2/6; dr^2/3]/2; %lokln vektor prav strany %vydlit njakou hodnotou a pro??
                        else
                            be=[0;0]; %nulov vkon ve vrstv Helia a pokryt
                        end
                        
                        %naten hodnot do globln matice tuhosti A
                        kam=ilok(ij,:);
                        for il=1:length(kam)
                            for im=1:length(kam)
                                if kam(il)~=0 && kam(im)~=0
                                    A(kam(il),kam(im))=A(kam(il),kam(im))+Ae(il,im);
                                end
                            end
                            b(kam(il))=b(kam(il))+be(il);
                        end
                    end
            end
        end
        
        %vyeen soustavy rovnic
        if volba==4
            %zahrnut Dirichletovy okrajov podmnky (MKP)
            b=b-A(:,end)*Tpoc;
            %vpoet soustavy MKP
            Thled(1:end-1)=(A(1:end-1,1:end-1))\b(1:end-1);
            Thled(end)=Tpoc;
        else
            Thled=A\b;
        end
        
        iterace1=iterace1+1;
        maxRezT=max(abs(Tpom(:)-Thled(:)));
    end
    
    %uloen do globlnch matic teploty a tepeln vodivosti labmda
    globT(ii,:)=Thled';
    globLambdai(ii,:)=lambdai(1:end-1)';
end


%-------------------------------------------------------------------------------
%-------vkreslovn geometrie a rozloen teplot---------
%vykreslen rozloen teploty v rmci geometrie
figure
for ii=1:m
    for ij=1:round(n)
        %pevod z polrnch souadnic
        rr1=dr*(ij-1);
        rr2=dr*ij;
        
        fi1=(ii/m)*(2*pi);
        fi2=((ii+1)/m)*(2*pi);
        
        x1=rr1*cos(fi1);
        x2=rr2*cos(fi1);
        x3=rr2*cos(fi2);
        x4=rr1*cos(fi2);
        
        y1=rr1*sin(fi1);
        y2=rr2*sin(fi1);
        y3=rr2*sin(fi2);
        y4=rr1*sin(fi2);
        
        if ii==m
            t1=globT(ii,ij);
            t2=globT(ii,ij+1);
            t3=globT(1,ij+1);
            t4=globT(1,ij);
        else
            t1=globT(ii,ij);
            t2=globT(ii,ij+1);
            t3=globT(ii+1,ij+1);
            t4=globT(ii+1,ij);
        end
        
        %vdy prvky mezi sly 2,3 a 4,1
        tpom1=linspace(fi1,fi2);
        xpom1=rr2*cos(tpom1);
        ypom1=rr2*sin(tpom1);
        zpom1=zeros(1,length(tpom1)); %hodnota aproximace mezi tetm a tvrtm vrcholem
        
        tpom2=linspace(fi2,fi1);
        xpom2=rr1*cos(tpom2);
        ypom2=rr1*sin(tpom2);
        zpom2=zeros(1,length(tpom2));
        
        for is=1:length(tpom1)
            vahapom=is/length(tpom1);
            zpom1(is)=vahapom*t3+(1-vahapom)*t2;
            zpom2(is)=vahapom*t1+(1-vahapom)*t4;
        end
        
        h=patch([x1 0; x2 0; xpom1' zeros(length(xpom1),1); x3 0; x4 0; xpom2' zeros(length(xpom2),1)],...
            [y1 0; y2 0; ypom1' zeros(length(ypom1),1); y3 0; y4 0; ypom2' zeros(length(ypom2),1)],...
            [t1 0;t2 0; zpom1' zeros(length(zpom1),1); t3 0; t4 0; zpom2' zeros(length(zpom2),1)]);
        hold on
        set(h,'EdgeColor','none') %pkaz odstraujc obrysy vykreslovanch konench prvk
    end
    
end

%vyznaen rozhran mezi materilovmi vrstvami
t=0:.1:3*pi;
plot(r1*cos(t),r1*sin(t),'k','LineWidth',1);
plot(r2*cos(t),r2*sin(t),'k','LineWidth',1);
plot(r3*cos(t),r3*sin(t),'k','LineWidth',2);

col=colorbar;
colormap jet;
xlabel('Souadnice x [m]')
ylabel('Souadnice y [m]')
caxis([min(min(globT)) max(max(globT))])
set(get(col,'title'),'string','[^oC]');
set(gcf,'units','points','position',[0,0,720,720])
upravaGrafu(0,0);

%vykreslen teplot na jednom paprsku
paprsek=1;
r=0:dr:r3;
figure
plot(r,globT(paprsek,:),'LineWidth',2);
xlabel('Radiln souadnice r [m]')
ylabel('Teplota T [^{\circ}C]')
xlim([r(1) r(end)])
%title(sprintf('Radiln rozloen teploty pro hel phi= %.3f pi rad', paprsek/(m-1)*2));
upravaGrafu(0,0);

%vykreslen prbhu souinitele teplotn vodivosti pro konkrtn paprsek a velikosti zmny teploty v jednotlivch krocch
zmenaT=zeros(1,length(globT(paprsek,:))-1);

for ii=1:length(zmenaT)
    zmenaT(ii)=globT(paprsek,ii+1)-globT(paprsek,ii);
end

figure
yyaxis left
plot(r,globLambdai(paprsek,:),'LineWidth',2)
xlabel('Radiln souadnice r [m]')
ylabel('Tepeln vodivost \lambda [Wm^{-1}K^{-1}]')
xlim([r(1) r(end)])
ylim([min(globLambdai(paprsek,:))-2 max(globLambdai(paprsek,:))+2])

yyaxis right
plot(r(2:end),zmenaT,'LineWidth',2);
ylabel('Zmna teploty \Delta T [^{\circ}C]')
ylim([min(zmenaT)-0.5 max(zmenaT)+0.5])
%title(sprintf('Radiln rozloen tepeln vodivosti a zmny teplot pro phi= %.3f pi rad', paprsek/(m-1)*2));
upravaGrafu(0,0);

%vykreslen prbhu Dirichletovy okrajov podmnky na hranici proutku
fi=Tokr(1,:)*2*pi;
figure
plot(fi,Tokr(2,:),'LineWidth',2)
xlabel('hel natoen \phi [rad]');
ylabel('Teplota T [^{\circ}C]');
xlim([0 2*pi])
set(gca,'XTick',0:pi/2:2*pi) 
set(gca,'XTickLabel',{'0','\pi/2','\pi','3/2\pi','2\pi'})
%title('Prbh okrajov Dirichletovy podmnky na hranici geometrie');
ylim([min(Tokr(2,:))*0.9995 max(Tokr(2,:))*1.0005])
upravaGrafu(0,0);