%-------DIPLOMOV PRCE---------
% ====================================
% LOHA VEDEN TEPLA V PALIVOVM PROUTKU
% SROVNN NUMERICKCH PSTUP S KVAZIANALYTICKM EENM
% ====================================
% Autor: Marek Blohoubek
% Verze: 1.0
% Datum: 2020
% ====================================
% <<<<<< INPUTS
% r1,r2,r3 - geometrick charakteristiky palivovho proutku
% proutek,axVrstva,dr,mocnina,n,m,vyhoreni,vyberPaprsku,epsilonT - parametry vpotu
% T,vykon,vlastnosti - vstupn matice subkanlov analzy
% cp,eta - vlastnosti vody pi konstantnm tlaku
% >>>>>> OUTPUTS
% globT,globLambdai - pole vstupnch veliin teploty a tepeln vodivosti v rmci geometrie
% grafick vstupy  - teplotn pole vybranho palivovho proutku
%                   - prbh teploty, jej zmny a tepeln vodivosti ve smru radiln souadnice pro vybran paprsek
%                   - funkce Dirichletovy okrajov podmnky na hranici proutku

clc
%clear all
close all

%-------vstupn geometrick parametry---------
r1=7.8e-3/2; %polomr vrstvy paliva [m]
r2=7.93e-3/2; %polomr vnj vrstvy (horn hranice haliov mezery) [m]
r3=9.1e-3/2; %polomr proutku [m]

%-------vstupn vpotov parametry---------
proutek=4; %vbr analyzovanho proutku
axVrstva=length(T); %vbr ax. vrstvy, pro n budeme teplotn analzu provdt
dr=r3/140; %dlka prostorovho kroku v radilnm smru [m] (obvykle 280)
mocnina=2; %hodnota mocniny proloen okrajov podmnky
n=r3/dr; %poet iterac v radilnm smru (poet prvk=n+1)
vyhoreni=41.3; %vyhoen paliva [MW d / kg U]
prolozeni=8; %mocnina proloen tepeln vodivosti
epsilonT=1; %hodnota zastavovac podmnky pro iterovn teplot v rmci jednoho paprsku [C]
pocetProutku=19; %celkov poet palivovch proutk
m=24; %celkov poet paprsku v rmci geometrie
vyberPaprsku=1; %vbr paprsku z 24 monch (veden tepla ve smu hlu pi/12)

%-------------------------------------------------------------------------------
%-------deklarace okrajov podmnky---------
zas=[1/6 1/3 1/4 1/12]; %mon zastoupen subkanl u jednotlivch proutk

%kad dek pedstavuje sousedn subkanly jednoho z proutk (v pravotoivm systm od nuly do 360)
%prvn a posledn subkanly jsou toton (kvli rotaci)
%proutky s menm potem soused maj posledn prvky dek nulov
soup=[3 2 1 6 5 4 3 2; 1 8 7 24 23 6 1 8; 11 10 9 8 1 2 11 10; 13 12 11 2 3 14 13 12; ...
    12 14 3 4 17 16 12 14; 17 4 5 20 19 18 17 4; 5 6 23 22 21 20 5 6; 7 25+zas(2) 36+zas(2) 24 7 25+zas(2) 0 0; ...
    9 26+zas(3) 25+zas(3) 7 8 9 26+zas(3) 0; 27+zas(2) 26+zas(2) 9 10 27+zas(2) 0 0 0; ...
    28+zas(3) 27+zas(3) 10 11 12 28+zas(3) 0 0; 29+zas(2) 28+zas(2) 12 13 29+zas(2) 28+zas(2) 0 0; ...
    29+zas(3) 13 14 15 30+zas(3) 29+zas(3) 0 0; 30+zas(2) 15 16 31+zas(2) 30+zas(2) 0 0 0; ...
    31+zas(3) 16 17 18 32+zas(3) 31+zas(3) 16 0; 32+zas(2) 18 19 33+zas(2) 32+zas(2) 18 0 0; ...
    19 20 21 34+zas(3) 33+zas(3) 19 20 0; 21 22 35+zas(2) 34+zas(2) 21 22 0 0; ...
    23 24 36+zas(3) 35+zas(3) 22 23 24 0];

for ii=1:length(soup)
    for ij=1:length(soup(1,:))
        if mod(soup(ii,ij),1)==0 && soup(ii,ij)~=0
            soup(ii,ij)=soup(ii,ij)+zas(1);
        end
    end
end

startPozice=zeros(1,pocetProutku);
startPozice(1:11)=-zas(1);
startPozice(12:end)=[-zas(2) -zas(4) -zas(1) -zas(3) -zas(2) -zas(1) -zas(1) -zas(1)];

Tsub=zeros(2,length(soup(1,:))+1); %matice teplot v subkanlech kolem proutk
for ii=1:length(soup(1,:))
    if soup(proutek,ii)~=0
        if ii==1
            Tsub(1,ii)=startPozice(proutek)+mod(soup(proutek,ii),1)/2;
        else
            Tsub(1,ii)=Tsub(1,ii-1)+mod(soup(proutek,ii-1),1)/2+mod(soup(proutek,ii),1)/2;
        end
        
        Tsub(2,ii)=T(fix(soup(proutek,ii)),axVrstva);
    end
end

%oznut vektoru od pebytench hodnot
orez=find(Tsub(1,:)==0);
Tsub=Tsub(:,1:orez(1)-1);
dphi=0.01; %velikost mrnho hlovho kroku
phi=Tsub(1,1):dphi:Tsub(1,end);
Tokr=zeros(3,length(phi)); %vektor teplotn okrajov podmnky
%(dkov) struktura:| hel natoen | teplota v subkanle | teplota na stn |
Tokr(1,:)=phi;

for ii=1:length(Tokr)
    pom=1;
    while Tokr(1,ii)>=Tsub(1,pom)
        pom=pom+1;
    end
    pomer1=abs(Tsub(1,pom-1)-Tokr(1,ii))^mocnina;
    pomer2=abs(Tsub(1,pom)-Tokr(1,ii))^mocnina;
    delkaKroku=pomer1+pomer2;
    pomer1=pomer1/delkaKroku; %normalizace
    pomer2=pomer2/delkaKroku;
    
    Tokr(2,ii)=pomer1*Tsub(2,pom)+pomer2*Tsub(2,pom-1);
    
    %vpoet teplotn okr. podmnky na stn proutku
    %vpoet souinitele pestupu tepla alfa [W / m2 K]
    index1=vyhledejIndex(T2,Tokr(2,ii)); %hledn prvku s nejbli hodnotou teploty pro ii-t prvek
    subkanal=fix(soup(proutek,pom));
    subkanalvedl=fix(soup(proutek,pom-1));
    
    %vpoet Nusseltova sla
    Pr=(eta(2,index1)*cp(2,index1))/lambda(2,index1); %Prandtlovo slo [-]
    dh=4*(pomer1*vlastnosti(1,subkanal)+pomer2*vlastnosti(1,subkanalvedl))/(pomer1*vlastnosti(6,subkanal)+pomer2*vlastnosti(6,subkanalvedl)); %hydraulick prmr [m]
    G=(pomer1*M(subkanal,axVrstva)+pomer2*M(subkanalvedl,axVrstva))/(pomer1*vlastnosti(1,subkanal)+pomer2*vlastnosti(1,subkanalvedl)); %hustota hmotnostnho toku [kg / m2 s1]
    Re=G*dh/eta(2,index1); %Reynoldsovo slo [-]
    Nu=0.023*Re^0.8*Pr^0.43;
    
    alfa=Nu*lambda(2,index1)/dh; %souinitel pestupu tepla [W / m2 K]
    Apom=2*pi*r3*L;
    Tokr(3,ii)=Tokr(2,ii)+(vykon(proutek)/Apom)/alfa;
end

uhel=vyberPaprsku/m; %slo nlec (0;1)
indexT=vyhledejIndex(Tokr(1,:),uhel);
Tpoc=Tokr(3,indexT);

%-------------------------------------------------------------------------------
%-------vpoet pomocnch veliin---------
qgen=vykon(proutek)/(pi*r1^2*L); %objemov hustota tepelnho toku [W / m3]
tildeq=vykon(proutek)/(L*100); %linern tepeln vkon [W / cm]
T3=19.85:1:500; %vektor teploty pro vpoet tepeln vodivosti lambda

%-------vpoet souinitele tepeln vodiviosti labmda pro jendnotliv vsrtvy---------
%vpoet souinitele tepeln vodivosti lambda pro zirkonov pokryt [W / m K]
lambdaPok=zeros(1,length(T3));
for ii=1:length(T3)
    lambdaPok(ii)=6.50e-17*T3(ii)^6-2.51e-13*T3(ii)^5+3.36e-10*T3(ii)^4-...
        1.74e-7*T3(ii)^3+2.35e-5*T3(ii)^2+1.17e-2*T3(ii)+1.70e1; %tepeln vodivost pokryt [W / m K]
end

%vpoet souinitele tepeln vodivosti lambda pro heliovou mezeru [W / m K]
alfaMtab=[0.0 20.8 41.3 57.0 70.8 79.0; ...
    2848.5 4422.7 8761.8 7511.9 4474.4 5926.8; ...
    3220 4891 10717 11518 11970 7963; ...
    3608 5824 15553 15311 12752 8938; ...
    4047 7074 21612 16191 13621 9774; ...
    4475 8258 22436 17073 14416 10506];
%matice souinitel prostupu tepla v zvislosti na linernm vkonu a vyhoen paliva
%dkov struktura: | vyhoen paliva | vkon 0 | vkon 50 | 100 | 150 | 200 |

%proloen polynomem
vykonyAlfa=[0 50 100 150 200]; %vektor vkon souinitele prostupu tepla
indexVyhoreni=find(vyhoreni==alfaMtab(1,:));
p1=polyfit(vykonyAlfa',alfaMtab(2:end,indexVyhoreni),prolozeni/2);

dq=1; %iteran krok pro prokldn linernho vkonu tildeq
vykony=vykonyAlfa(1):dq:vykonyAlfa(end);
alfaM=zeros(2,length(vykony)); %matice souinitele prostupu tepla pro vybran vyhoen
alfaM(1,:)=vykony;
alfaM(2,:)=polyval(p1,alfaM(1,:));

alfaMOpt=alfaM(2,vyhledejIndex(alfaM(1,:),tildeq));
lambdaHel=alfaMOpt*r2*log(r2/r1); %tepeln vodivost heliov vrstvy [W / m K]

%vpoet souinitele tepeln vodivosti lambda pro palivo [W / m K]
lambdaPalZadane=[300 500 700 900 1100 1300 1500 1700 1900 2100 2300 2500 2700 2900;...
    8.42 6.26 4.98 4.14 3.56 3.15 2.86 2.66 2.54 2.51 2.55 2.67 2.89 3.20;...
    3.85 3.32 2.94 2.72 2.61 2.52 2.42 2.34 2.30 2.31 2.38 2.54 2.77 3.10;...
    3.10 2.75 2.49 2.34 2.29 2.25 2.19 2.15 2.13 2.17 2.26 2.43 2.68 3.01;...
    2.73 2.45 2.25 2.13 2.11 2.09 2.05 2.02 2.03 2.08 2.18 2.36 2.61 2.96;...
    2.48 2.25 2.08 1.99 1.97 1.96 1.94 1.93 1.94 2.00 2.12 2.30 2.56 2.91;...
    2.35 2.15 1.99 1.91 1.90 1.90 1.89 1.88 1.90 1.96 2.08 2.27 2.53 2.89];
%matice tepeln vodivosti pro rzn teploty a hodnoty vyhoen
%(dkov) struktura: teploty [K] | vyhoen 0.0 | vyhoen 20.8 | vyhoen
%41.3 | vyhoen 57.0 | vyhoen 70.8 | 79.0 |

lambdaPalZadane(1,:)=lambdaPalZadane(1,:)-273.15;
dT=10;
lambdaPal=zeros(2,round((lambdaPalZadane(1,end)-lambdaPalZadane(1,1))/dT+1));

%proloen polynomem
p1=polyfit(lambdaPalZadane(1,:),lambdaPalZadane(indexVyhoreni+1,:),prolozeni);
lambdaPal(1,:)=lambdaPalZadane(1,1):dT:lambdaPalZadane(1,end);
lambdaPal(2,:)=polyval(p1,lambdaPal(1,:));

%kontroln vykreslen proloench hodnot
figure
plot(lambdaPalZadane(1,:),lambdaPalZadane(indexVyhoreni+1,:),'o', 'Linewidth', 2)
hold on
plot(lambdaPal(1,:),lambdaPal(2,:), 'Linewidth', 2)
xlabel('Teplota T [^\circC]')
ylabel('Tepeln vodivost \lambda [W \cdot m^{-1} \cdot K^{-1}]');
leg=legend('Prokldan hodnoty','Proloen polynomem 8.stupn');
upravaGrafu(1,leg);

%-------------------------------------------------------------------------------
%---------Vpoet rozloen teploty v proutku v rmci jednoho paprsku-----------
globT=zeros(m,round(n)+1); %globln matice teplot
globLambdai=zeros(m,round(n)+1); %globln matice tepeln vodivosti

Tpomc=zeros(n+1,1); %vektor teplot pro jeden radiln "paprsek"
Tpomd=zeros(n+1,1);
Tpoma=zeros(n+1,1);
Tpommko=zeros(n+1,1);
Tpommkp=zeros(n+1,1);

Thledc=zeros(n+1,1); %vektor hledanch teplot (pro jeden radiln paprsek)
Thledd=zeros(n+1,1);
Thleda=zeros(n+1,1);
Thledmko=zeros(n+1,1);
Thledmkp=zeros(n+1,1);

lambdaic=zeros(1,n+2); %vektor souinitele tepeln vodivosti
lambdaid=zeros(1,n+2);
lambdaia=zeros(1,n+2);
lambdaimko=zeros(1,n+2);
lambdaimkp=zeros(1,n+2);

Ac=zeros(n+1,n+1); %matice koef. jednotlivch teplot
bc=zeros(n+1,1); %vektor prav strany (pro Q)
Ad=zeros(n+1,n+1);
bd=zeros(n+1,1);
Amko=zeros(n+1,n+1);
bmko=zeros(n+1,1);

%potebn deklarace promnnch pro poteby MKP (celkov poetKP=n, celkov poet Uzl=n+1)
%lokalizan matice a matice globlnch souadnic uzl
ilok=zeros(n,2); %lokalizan matice (1 prvek = 1 dek)
for ii=1:n
    ilok(ii,1)=ii;
    ilok(ii,2)=ii+1;
end

sourR=zeros(n,2); %globln matice r-ovch souadnic (1 prvek = 1 dek)
for ii=1:n
    sourR(ii,1)=(ii-1)*dr;
    sourR(ii,2)=sourR(ii,1)+dr;
end

%-------iteran vpoet pes jeden paprsek--------
iterace1=1;
maxRezT=2000;

while maxRezT>epsilonT %rozdl mezi dvma po sob jdoucmi iteracemi
    Tpomc=Thledc;
    Tpomd=Thledd;
    Tpommko=Thledmko;
    Tpommkp=Thledmkp;
    
    %matice tuhosti a vektor pravch stran pro MKP
    K=zeros(n+1,n+1); %globln matice tuhosti
    f=zeros(n+1,1); %globln vektor pravch stran
    
    for ij=1:n+1
        ri=(ij-1)*dr; %souadnice v radilnm smru (aktuln polomr)
        
        %uren hodnoty lambda pro hladinu ij a ij+1
        if iterace1==1 %poten "nstel" hodnot lambdai
            if ri>=r2 %odpovd teplot 319 C
                lambdaic(ij)=lambdaPok(31);
                lambdaid(ij)=lambdaPok(31);
                lambdaimko(ij)=lambdaPok(31);
                lambdaimko(ij+1)=lambdaPok(31);
                lambdaimkp(ij)=lambdaPok(31);
                lambdaimkp(ij+1)=lambdaPok(31);
            elseif ri>r1
                lambdaic(ij)=lambdaHel;
                lambdaid(ij)=lambdaHel;
                lambdaimko(ij)=lambdaHel;
                lambdaimko(ij+1)=lambdaHel;
                lambdaimkp(ij)=lambdaHel;
                lambdaimkp(ij+1)=lambdaHel;
            else %odpovd teplot 427 C
                lambdaic(ij)=lambdaPal(2,3);
                lambdaid(ij)=lambdaPal(2,3);
                lambdaimko(ij)=lambdaPal(2,3);
                lambdaimko(ij+1)=lambdaPal(2,3);
                lambdaimkp(ij)=lambdaPal(2,3);
                lambdaimkp(ij+1)=lambdaPal(2,3);
            end
        else
            if ri>=r2 %vrstva pokryt
                index2c=vyhledejIndex(T3,Tpomc(ij));
                index2d=vyhledejIndex(T3,Tpomd(ij));
                index2mko=vyhledejIndex(T3,Tpommko(ij));
                index2mkp=vyhledejIndex(T3,Tpommkp(ij));
                if ij~=n+1
                    index3c=vyhledejIndex(T3,Tpomc(ij+1));
                    index3d=vyhledejIndex(T3,Tpomd(ij+1));
                    index3mko=vyhledejIndex(T3,Tpommko(ij+1));
                    index3mkp=vyhledejIndex(T3,Tpommkp(ij+1));
                end
                lambdaic(ij)=lambdaPok(index2c);
                lambdaid(ij)=lambdaPok(index2d);
                lambdaimko(ij)=lambdaPok(index2mko);
                lambdaimko(ij+1)=lambdaPok(index3mko);
                lambdaimkp(ij)=lambdaPok(index2mkp);
                lambdaimkp(ij+1)=lambdaPok(index3mkp);
            elseif ri>r1 %vrstva helia
                lambdaic(ij)=lambdaHel;
                lambdaid(ij)=lambdaHel;
                lambdaimko(ij)=lambdaHel;
                lambdaimkp(ij)=lambdaHel;
            else %vrstva paliva
                index2c=vyhledejIndex(lambdaPal(1,:),Tpomc(ij));
                index2d=vyhledejIndex(lambdaPal(1,:),Tpomd(ij));
                index2mko=vyhledejIndex(lambdaPal(1,:),Tpommko(ij));
                index2mkp=vyhledejIndex(lambdaPal(1,:),Tpommkp(ij));
                if ij~=n+1
                    index3c=vyhledejIndex(lambdaPal(1,:),Tpomc(ij+1));
                    index3d=vyhledejIndex(lambdaPal(1,:),Tpomd(ij+1));
                    index3mko=vyhledejIndex(lambdaPal(1,:),Tpommko(ij+1));
                    index3mkp=vyhledejIndex(lambdaPal(1,:),Tpommkp(ij+1));
                end
                lambdaic(ij)=lambdaPal(2,index2c);
                lambdaid(ij)=lambdaPal(2,index2d);
                lambdaimko(ij)=lambdaPal(2,index2mko);
                lambdaimko(ij+1)=lambdaPal(2,index3mko);
                lambdaimkp(ij)=lambdaPal(2,index2mkp);
                lambdaimkp(ij+1)=lambdaPal(2,index3mkp);
            end
        end
        
        %-------------------------------------------------------------------------------
        %veden tepla ty: centrln diferenn schma
        if ij==1
            Ac(ij,ij)=-1; %matice A centrlnho dif. schmatu
            Ac(ij,ij+1)=1;
        elseif ij==n+1
            tilder=r1;
            Ac(ij,ij-1)=1;
            bc(ij)=(dr*tilder^2*qgen)/(lambdaic(ij)*ri)+Tpoc;
        else
            if ri<=r1
                tilder=ri;
            else
                tilder=r1;
            end
            
            Ac(ij,ij+1)=1;
            Ac(ij,ij-1)=-1;
            bc(ij)=-(dr*tilder^2*qgen)/(lambdaic(ij)*ri);
        end
        
        %-------------------------------------------------------------------------------
        %veden tepla ty: dopedn diferenn schma
        if ij==1
            Ad(ij,ij)=-1;
            Ad(ij,ij+1)=1;
        elseif ij==n+1
            tilder=r1;
            Ad(ij,ij)=1;
            bd(ij)=(dr*tilder^2*qgen)/(2*lambdaid(ij)*ri)+Tpoc;
        else
            if ri<=r1
                tilder=ri;
            else
                tilder=r1;
            end
            
            Ad(ij,ij+1)=1;
            Ad(ij,ij)=-1;
            bd(ij)=-(dr*tilder^2*qgen)/(2*lambdaid(ij)*ri);
        end
        
        %-------------------------------------------------------------------------------
        %veden tepla ty: metoda konench objem
        rplus=ri+dr/2;
        rminus=ri-dr/2;
        if ij==1
            lambdaiminus=lambdaimko(ij);
            lambdaiplus=(lambdaimko(ij+1)+lambdaimko(ij))/2;
            rminus=ri;
        elseif ij==n+1
            lambdaiplus=lambdaimko(ij)/2;
            lambdaiminus=(lambdaimko(ij-1)+lambdaimko(ij))/2;
            rplus=ri;
        else
            lambdaiplus=(lambdaimko(ij+1)+lambdaimko(ij))/2;
            lambdaiminus=(lambdaimko(ij-1)+lambdaimko(ij))/2;
        end
        
        ia=lambdaiplus*rplus/dr;
        ib=lambdaiminus*rminus/dr;
        if ri>r1
            ic=0;
        else
            ic=-qgen*dr*ri;
        end
        
        if ij==1
            Amko(ij,ij)=-1;
            Amko(ij,ij+1)=1;
        elseif ij==n+1
            Amko(ij,ij)=-(ia+ib);
            Amko(ij,ij-1)=ib;
            bmko(ij)=ic-ia*Tpoc;
        else
            Amko(ij,ij+1)=ia;
            Amko(ij,ij)=-(ia+ib);
            Amko(ij,ij-1)=ib;
            bmko(ij)=ic;
        end
        
        %-------------------------------------------------------------------------------
        %veden tepla ty: metoda konench prvk
        if ij~=n+1
            er=sourR(ij,:)'; %globln r-ov souadnice analyzovanho prvku
            
            lambdaMKP=(lambdaimkp(ij)+lambdaimkp(ij+1))/2; %souinitel tepeln vodivosti povaujeme na KP za konstantn - bereme aritmetick prmr z uzlovch hodnot
            Ke=[1 -1;-1 1]*lambdaMKP/2; %lokln matice tuhosti
            if er(2)<=r1
                fe=qgen*[dr^2/6; dr^2/3]/2; %lokln vektor prav strany
            else
                fe=[0;0]; %nulov vkon ve vrstv Helia a pokryt
            end
            
            %naten hodnot do globln matice tuhosti K
            kam=ilok(ij,:);
            for il=1:length(kam)
                for im=1:length(kam)
                    if kam(il)~=0 && kam(im)~=0
                        K(kam(il),kam(im))=K(kam(il),kam(im))+Ke(il,im);
                    end
                end
                f(kam(il))=f(kam(il))+fe(il);
            end
            
        end
        
    end
    
    Thledc=Ac\bc;
    Thledd=Ad\bd;
    Thledmko=Amko\bmko;
    
    %zahrnut Dirichletovy okrajov podmnky (MKP)
    f=f-K(:,end)*Tpoc;
    %vpoet soustavy MKP
    Thledmkp(1:end-1)=K(1:end-1,1:end-1)\f(1:end-1);
    Thledmkp(end)=Tpoc;
    
    %-------------------------------------------------------------------------------
    iterace1=iterace1+1;
    disp(iterace1)
    %vbr nejvt hodnoty rezidua
    maxRezTc=max(abs(Tpomc(:)-Thledc(:)));
    maxRezTd=max(abs(Tpomd(:)-Thledd(:)));
    maxRezTmko=max(abs(Tpommko(:)-Thledmko(:)));
    maxRezTmkp=max(abs(Tpommkp(:)-Thledmkp(:)));
    
    maxRezT=max([maxRezTc maxRezTd maxRezTmko maxRezTmkp]);
end

%ukldn do globln matice teplot
globT(1,:)=Thledc';
globLambdai(1,:)=lambdaic(1:end-1)';
globT(2,:)=Thledd';
globLambdai(2,:)=lambdaid(1:end-1)';
globT(3,:)=Thledmko';
globLambdai(3,:)=lambdaimko(1:end-1)';
globT(4,:)=Thledmkp';
globLambdai(4,:)=lambdaimkp(1:end-1)';

%-------------------------------------------------------------------------------
%vpoet zvislosti tepeln vodivosti na radiln souadnici (data vychz z prmru numerickch metod)
rpal=0:dr:r1-dr;
rpok=r2:dr:r3;
r=0:dr:r3;

lambdaPalivo=(globLambdai(1,1:length(rpal))+globLambdai(2,1:length(rpal))+globLambdai(3,1:length(rpal))+globLambdai(4,1:length(rpal)))/4;
if length(rpok)==length(globLambdai(1,find(abs(r-r2)<dr/2)+1:end))
    lambdaPokryti=(globLambdai(1,find(abs(r-r2)<dr/2)+1:end)+globLambdai(2,find(abs(r-r2)<dr/2)+1:end)+globLambdai(3,find(abs(r-r2)<dr/2)+1:end)+globLambdai(4,find(abs(r-r2)<dr/2)+1:end))/4;
else
    lambdaPokryti=(globLambdai(1,find(abs(r-r2)<dr/2):end)+globLambdai(2,find(abs(r-r2)<dr/2):end)+globLambdai(3,find(abs(r-r2)<dr/2):end)+globLambdai(4,find(abs(r-r2)<dr/2):end))/4;
end

%vrstva paliva
%proloen hodnot exponenciolou ve tvaru b1+b2*e^(r/b3)
fceProklad=@(b) sum((lambdaPalivo-(b(1)+b(2).*exp(rpal/b(3)))).^2); %definice prokldan funkce
fceMin=@(b,paramT) b(1)+b(2).*exp(paramT/b(3)); %funkce k nalezen minima odchylky ve smyslu nejmench tverc
b0=[min(lambdaPalivo),max(lambdaPalivo)-min(lambdaPalivo),rpal(end)/3]; %Inital guesses

koefLambdaPal=fminsearch(fceProklad,b0); %hodnoty koeficient nelin. proloen
lambdaPalivoProlozeni=fceMin(koefLambdaPal,rpal); %hodnoty fce ve vebranch bodech

%vrstva pokryt
%proloen hodnot polynomem stupn 1
koefLambdaPok=polyfit(rpok,lambdaPokryti,1);
lambdaPokrytiProlozeni=polyval(koefLambdaPok,rpok);

%-------------------------------------------------------------------------------
%kontroln vykreslen (srovnn hodnot pro proloen, nejdve pro palivo, pot pro pokryt)
figure
plot(rpal,lambdaPalivo,'Linewidth',2)
hold on
plot(rpal,lambdaPalivoProlozeni,'LineWidth',2)
xlim([rpal(1) rpal(end)])
xlabel('Radiln souadnice r [m]')
ylabel('Tepeln vodivost \lambda [W \cdot m^{-1} \cdot K^{-1}]');
legend('Pvodn hodnoty neznm zvislosti','Proloen exponenciln funkc');
upravaGrafu(1,leg);

figure
plot(rpok,lambdaPokryti,'Linewidth',2)
hold on
plot(rpok,lambdaPokrytiProlozeni,'LineWidth',2)
xlim([rpok(1) rpok(end)]);
xlabel('Radiln souadnice r [m]')
ylabel('Tepeln vodivost \lambda [W \cdot m^{-1} \cdot K^{-1}]');
legend('Pvodn hodnoty neznm zvislosti','Proloen polynomem 1.stupn');
upravaGrafu(1,leg);

%-------------------------------------------------------------------------------
%veden tepla ty: pln analytick een
Thleda(1)=Tpoc;
bb=koefLambdaPok; %vektor koeficient aproximanho polynomu pro lambdaPok
b=koefLambdaPal; %deklarace pro zjednoduen zpis nsledujcho vrazu
fceIntegral=@(r) (r*(r-2*b(3)*log(b(2)*exp(r/b(3))/b(1)+1))-...
    2*b(3)^2*polylog(2,-b(2)*exp(r/b(3))/b(1)))/(2*b(1)); %pomocn integrl pro vpoet v mst paliva

for ii=1:length(Thleda)-1
    rakt=r3-ii*dr;
    if rakt>=r2 %vrstva pokryti 
        Thleda(ii+1)=Tpoc+(qgen*r1^2)/(2*bb(2))*((log(r3)-log(bb(1)*r3+bb(2)))-(log(rakt)-log(bb(1)*rakt+bb(2))));
        Tr2=Thleda(ii+1);
    elseif rakt>=r1 %heliova vrstva
        Thleda(ii+1)=Tr2+(qgen*r1^2)/(2*lambdaHel)*(log(r2)-log(rakt));
        Tr1=Thleda(ii+1);
    else %vrstva paliva
        Thleda(ii+1)=Tr1+(qgen/2)*(fceIntegral(r1)-fceIntegral(rakt));
    end
end

Thleda=fliplr(Thleda');
lambdaia=fliplr(lambdaia);
globT(5,:)=Thleda;
globLambdai(5,:)=(globLambdai(1,:)+globLambdai(2,:)+globLambdai(3,:))/3;

%-------------------------------------------------------------------------------
%----------Vykreslen teplot na jednom paprsku--------------
figure
plot(r,globT(1,:),'LineWidth',2);
hold on
plot(r,globT(2,:),'LineWidth',2)
plot(r,globT(3,:),'LineWidth',2)
plot(r,globT(4,:),'LineWidth',2)
plot(r,globT(5,:),'LineWidth',2)
%plot([r2 r2], [0 10000], 'k') %vykreslen rozhran helium-pokryt
%plot([r1 r1],[0 10000], 'k') %vykreslen rozhran palivo-helium
xlabel('Radiln souadnice r [m]')
xlim([r(1) r(end)])
ylabel('Teplota T [^{\circ}C]')
%ylim([0.8*min(globT(vyberPaprsku,:)) 1.2*max(globT(vyberPaprsku,:))])
% title(sprintf('Radiln rozloen teploty pro hel phi= %.3f pi rad', vyberPaprsku/(m-1)*2));
legend('CDS','DDS','MKO','MKP','Analytick een')
upravaGrafu(1,leg);

%-------------------------------------------------------------------------------
%vykreslen prbhu souinitele teplotn vodivosti a velikosti zmny teploty v jednotlivch krocch
zmenaT=zeros(5,length(globT(1,:))-1);

for ii=1:length(zmenaT)
    zmenaT(1,ii)=globT(1,ii+1)-globT(1,ii);
    zmenaT(2,ii)=globT(2,ii+1)-globT(2,ii);
    zmenaT(3,ii)=globT(3,ii+1)-globT(3,ii);
    zmenaT(4,ii)=globT(4,ii+1)-globT(4,ii);
    zmenaT(5,ii)=globT(5,ii+1)-globT(5,ii);
end

figure
for ii=1:5
    subplot(3,2,ii)
    yyaxis left
    plot(r,globLambdai(ii,:),'LineWidth',1.5)
    xlabel('Radiln souadnice r [m]')
    xlim([r(1) r(end)])
    ylabel('Tepeln vodivost \lambda [Wm^{-1}K^{-1}]')
    grid on
    
    plot(r(2:end),zmenaT(ii,:),'LineWidth',1.5)
    ylabel('Zmna teploty \Delta T [^{\circ}C]')
    hold on
    switch ii
        case 1
            legend('CDS')
        case 2
            legend('DDS')
        case 3
            legend('MKO')
        case 4
            legend('MKP')
        otherwise
            legend('Analytick een')
    end
end

%-------------------------------------------------------------------------------
%vykreseln rezidui pro rzn numerick pstupy v relaci z kvazianalytickm eenm
figure
rezic=abs(globT(1,:)-globT(5,:));
rezid=abs(globT(2,:)-globT(5,:));
rezimko=abs(globT(3,:)-globT(5,:));
rezimkp=abs(globT(4,:)-globT(5,:));

plot(r,rezic,'LineWidth',2)
hold on
plot(r,rezid,'LineWidth',2)
plot(r,rezimko,'LineWidth',2)
plot(r,rezimkp,'LineWidth',2)
xlabel('Radiln souadnice r [m]')
xlim([r(1) r(end)])
ylabel('Rozdl teploty Rez(T) [^{\circ}C]')
legend('CDS','DDS','MKO','MKP')
% title(sprintf('Hodnoty rezidua spoten jako rozdl numerick a analytick hodnoty teploty pro phi= %.3f pi rad', vyberPaprsku/(m-1)*2));
upravaGrafu(1,leg);